
#####################################################-
####   RScript Temporal Closure Models          #####-
####   Jesse Whittington                        #####-
####   2018-11-09                               #####-
#####################################################-

# sessionInfo()
# R version 3.5.1 (2018-07-02)
# glmmTMB version 0.2.2.0
# MuMIn version 1.42.1

library(glmmTMB)
library(MuMIn)
options(stringsAsFactors=FALSE)

#######################################-
### 1.  Import data and Top Models ####
#######################################-

#### 1a. Remote Camera Analysis  ####
camera <- read.csv('data_camera.csv')
m.camera <- glmmTMB(detect.01 ~  Elevation.c + may1.c + may1.c2 + sunriseset.c + HwyOverpassOpenspan + TreatmentArea * ClosedTime + (1|location), data = camera, family = 'binomial')     


#### 1b.  Road Survey Analysis ####
road <- read.csv('data_road_obs.csv')
m.road <- glmmTMB(detect.01 ~  may1.c + may1.c2 + TreatmentArea * ClosedTime  + (1|survey.id), data = road, family = 'binomial')

#### 1c.  Grizzly GPS Analysis  ####
grizzly <- read.csv('data_grizzly_gps.csv')
m.grizzly <- glmmTMB(road.01 ~ may1.c + TreatmentYear * ClosedTime  + (1|animal.id), data = grizzly, family = 'binomial')    


#######################################-
### 2.  Model selection with MuMIn  ####
#######################################-

#### 2a. Remote Camera Model selection  ####
#   NOTE - the camera models take several hours to run
m.full.cam <- glmmTMB(detect.01 ~ Elevation.c + HwyOverpassOpenspan + sunriseset.c + may1.c + may1.c2 + TreatmentArea * ClosedTime  + (1|location) + (1|survey.id), data = camera, family = 'binomial')
m.dredge.cam <- dredge(m.full.cam)             
m.sub.cam <- subset(m.dredge.cam, delta < 2 | df < 3)   
m.sub.cam

#### 2b.  Road Survey Model Selection ####
m.full.road <- glmmTMB(detect.01 ~  sunriseset.c + may1.c + may1.c2 + TreatmentArea * ClosedTime  + (1|survey.id), data = road, family = 'binomial')
m.dredge.road <- dredge(m.full.road)             
m.sub.road <- subset(m.dredge.road, delta < 2 | df < 3)   
m.sub.road

#### 2c.  Grizzly GPS Model Selection  ####
m.full.grizzly <- glmmTMB(road.01 ~ may1.c  + hour.sin +  TreatmentYear * ClosedTime + (1|animal.id), family = binomial, data = grizzly)
m.dredge.grizzly <- dredge(m.full.grizzly)              
m.sub.grizzly <- subset(m.dredge.grizzly, delta < 2 | df < 3)   
m.sub.grizzly


